<?php
/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) 2000-2011 LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

// {{{ requires
require_once CLASS_EX_REALDIR . 'page_extends/admin/LC_Page_Admin_Ex.php';

/**
 * コンテンツ管理 のページクラス.
 *
 * @package Page
 * @author LOCKON CO.,LTD.
 * @version $Id: LC_Page_Admin_Contents.php 20825 2011-04-08 08:28:06Z no61 $
 */
class LC_Page_Admin_Contents_Coupon extends LC_Page_Admin_Ex {

    /**
     * Page を初期化する.
     *
     * @return void
     */
    public function init() {
        parent::init();
        $this->tpl_mainpage = 'contents/coupon.tpl';
        $this->tpl_subnavi = 'contents/subnavi.tpl';
        $this->tpl_subno = 'coupon';
        $this->tpl_mainno = 'contents';
        $this->arrForm = array(
            'year' => date('Y'),
            'month' => date('n'),
            'day' => date('j'),
        );
		$this->tpl_maintitle = 'コンテンツ管理';
        $this->tpl_subtitle = 'クーポン管理';
        //---- 日付プルダウン設定
        $objDate = new SC_Date_Ex(ADMIN_NEWS_STARTYEAR);
        $this->arrYear = $objDate->getYear();
        $this->arrMonth = $objDate->getMonth();
        $this->arrDay = $objDate->getDay();
    }

    /**
     * Page のプロセス.
     *
     * @return void
     */
    public function process() {
        $this->action();
        $this->sendResponse();
    }

    /**
     * Page のアクション.
     *
     * @return void
     */
    public function action() {
        $objDb = new SC_Helper_DB_Ex();
        $objFormParam = new SC_FormParam_Ex();
	//パラメータの設定
        $this->lfInitParam($objFormParam);
	//POSTされた値をパラメータに設定
        $objFormParam->setParam($_POST);
	//パラメータを変換
        $objFormParam->convParam();
	//クーポンIDを取得
        $coupon_id = $objFormParam->getValue('coupon_id');

        //新規登録/編集登録
        switch ($this->getMode()) {
        case 'regist':
            //登録
	    //パラメータの取得
            $arrPost = $objFormParam->getHashArray();
	    //エラーチェック
            $this->arrErr = $this->lfCheckError($objFormParam);
            if (SC_Utils_Ex::isBlank($this->arrErr)) {
                //クーポンIDの値がPOSTされて来た場合は既存データの編集とみなし、
                //更新メソッドを呼び出す。
                //クーポンIDが存在しない場合は新規登録を行う。
                if (strlen($coupon_id) > 0 && is_numeric($coupon_id)) {
		    //更新
                    $this->lfCouponUpdate($arrPost);
                } else {
                    //新規登録
                    $this->lfCouponInsert($arrPost);
		}
		$coupon_id = "";
                $this->tpl_onload = "window.alert('編集が完了しました');";
            } else {
                //表示用の変数代入
                $this->arrForm = $arrPost;
            }
            break;
        case 'search':
            if (is_numeric($coupon_id)) {
                list($this->arrForm) = $this->getCoupon($coupon_id);
                list($this->arrForm['startyear'],$this->arrForm['startmonth'],$this->arrForm['startday']) = $this->splitCouponDate($this->arrForm['cast_start_date']);
                list($this->arrForm['endyear'],$this->arrForm['endmonth'],$this->arrForm['endday']) = $this->splitCouponDate($this->arrForm['cast_end_date']);
                $this->edit_mode = 'on';
            }
            break;
        case 'delete':
        //----　データ削除
            if (is_numeric($coupon_id)) {
                $this->deleteCoupon($coupon_id);
                SC_Response_Ex::reload();             //自分にリダイレクト（再読込による誤動作防止）
            }
            break;
        default:
            break;
        }

	//クーポン情報の取得
        $this->arrCoupon = $this->getCoupon();
	//表示用にクーポンIDの代入
        $this->tpl_coupon_id = $coupon_id;
	//クーポンの数取得
        $this->line_max = count($this->arrCoupon);
    }

    /**
     * 入力されたパラメータのエラーチェックを行う。
     * @param Object $objFormParam
     * @return Array エラー内容
     */
    public function lfCheckError(&$objFormParam){
        $objErr = new SC_CheckError_Ex($objFormParam->getHashArray());
	//パラメータのエラーチェック
        $objErr->arrErr = $objFormParam->checkError();
	//利用期間の入力チェック
        $objErr->doFunc(array("利用開始日", 'startyear', 'startmonth', 'startday'), array("CHECK_DATE"));
        $objErr->doFunc(array("利用終了日", 'endyear', 'endmonth', 'endday'), array("CHECK_DATE"));
        return $objErr->arrErr;
    }

    /**
     * パラメータの初期化を行う
     * @param Object $objFormParam
     */
    public function lfInitParam(&$objFormParam){
        $objFormParam->addParam("coupon_id", 'coupon_id', INT_LEN, 'n', array("NUM_CHECK", "MAX_LENGTH_CHECK"));
        $objFormParam->addParam("クーポン名", 'title', STEXT_LEN, '', array("EXIST_CHECK", "MAX_LENGTH_CHECK"));
        $objFormParam->addParam("割引額", 'discount', INT_LEN, 'n', array("EXIST_CHECK", "NUM_CHECK", "MAX_LENGTH_CHECK"));
        $objFormParam->addParam("日付(年)", 'startyear', INT_LEN, 'n', array("EXIST_CHECK", "NUM_CHECK", "MAX_LENGTH_CHECK"));
        $objFormParam->addParam("日付(月)", 'startmonth', INT_LEN, 'n', array("EXIST_CHECK", "NUM_CHECK", "MAX_LENGTH_CHECK"));
        $objFormParam->addParam("日付(日)", 'startday', INT_LEN, 'n', array("EXIST_CHECK", "NUM_CHECK", "MAX_LENGTH_CHECK"));
        $objFormParam->addParam("日付(年)", 'endyear', INT_LEN, 'n', array("EXIST_CHECK", "NUM_CHECK", "MAX_LENGTH_CHECK"));
        $objFormParam->addParam("日付(月)", 'endmonth', INT_LEN, 'n', array("EXIST_CHECK", "NUM_CHECK", "MAX_LENGTH_CHECK"));
        $objFormParam->addParam("日付(日)", 'endday', INT_LEN, 'n', array("EXIST_CHECK", "NUM_CHECK", "MAX_LENGTH_CHECK"));
    }

    /**
     * クーポンのデータの登録を行う
     * @param Array $arrPost POSTデータの配列
     */
    public function lfCouponInsert($arrPost){
        $objQuery = $objQuery =& SC_Query_Ex::getSingletonInstance();

        $table = 'dtb_coupon';//登録テーブル
        $sqlval = array();//登録用の配列
        $sqlval['title'] = $arrPost['title'];//クーポン名
        $sqlval['discount'] = $arrPost['discount'];//割引額
        $sqlval['exp_start_date'] = $this->getRegistDate(array($_POST['startyear'],$_POST['startmonth'],$_POST['startday']));//利用開始日
        $sqlval['exp_end_date'] = $this->getRegistDate(array($_POST['endyear'],$_POST['endmonth'],$_POST['endday']));//利用終了日
        $sqlval['create_date'] = 'now()';//作成日
        $sqlval['update_date'] = 'now()';//更新日
        $sqlval['coupon_id'] = $objQuery->nextVal('dtb_coupon_coupon_id'); //★PostgreSQLでエラーが発生しないように
        $objQuery->insert($table, $sqlval);

    }

    /**
     * クーポンの日付の値をフロントでの表示形式に合わせるために分割
     * @param String $news_date
     */
    public function splitCouponDate($coupon_date){
        return explode("-", $coupon_date);
    }

    //クーポンの更新
    public function lfCouponUpdate($arrPost){
        $objQuery = $objQuery =& SC_Query_Ex::getSingletonInstance();

        $table = 'dtb_coupon';//登録テーブル
        $sqlval = array();//登録用の配列
        $sqlval['title'] = $arrPost['title'];//クーポン名
        $sqlval['discount'] = $arrPost['discount'];//割引額
        $sqlval['exp_start_date'] = $this->getRegistDate(array($_POST['startyear'],$_POST['startmonth'],$_POST['startday']));//利用開始日
        $sqlval['exp_end_date'] = $this->getRegistDate(array($_POST['endyear'],$_POST['endmonth'],$_POST['endday']));//利用終了日
        $sqlval['update_date'] = 'now()';//更新日
        $where = 'coupon_id = ?';
        $arrValIn = array($arrPost['coupon_id']);//対象のクーポンID
        $objQuery->update($table, $sqlval, $where, $arrValIn);
    }

    /**
     * データの登録日を返す。
     * @param Array $arrPost POSTのグローバル変数
     * @return string 登録日を示す文字列
     */
    public function getRegistDate($arrPost){
	//ばらばらのデータをスラッシュ区切りの文字列に変換
        $registDate = $arrPost[0] ."/". $arrPost[1] ."/". $arrPost[2];
        return $registDate;
    }


    /**
     * クーポンを取得する。
     * @param Integer coupon_id クーポンID
     */
    public function getCoupon($coupon_id = ''){
        $objQuery = $objQuery =& SC_Query_Ex::getSingletonInstance();
	//取得カラム
	$col = '* ,cast(exp_start_date as date) as cast_start_date , cast(exp_end_date as date) as cast_end_date';
	//取得テーブル
        $table = 'dtb_coupon';
	//表示順序
        $order = 'update_date DESC';
        if(strlen($coupon_id) == 0){
	    //クーポンIDの指定がないならば
            $where = 'del_flg = 0';
            $arrval = array();
        }else{
            //クーポンIDの指定があるならば
            $where = 'del_flg = 0 AND coupon_id = ?';
            $arrval = array($coupon_id);
        }
	//表示順序の設定
        $objQuery->setOrder($order);
        return $objQuery->select($col, $table, $where,$arrval);
    }

    /**
     * クーポンを削除する。
     * @param Integer copupon_id クーポンID
     */
    public function deleteCoupon($coupon_id){
        $objQuery = $objQuery =& SC_Query_Ex::getSingletonInstance();
        $objQuery->begin();
	//対象テーブル
        $table = 'dtb_coupon';
        $sqlval = array();
	//削除フラグの設定
        $sqlval['del_flg'] = 1;
	//更新日の設定
        $sqlval['update_date'] = 'NOW()';
	//削除判定
        $where = 'coupon_id = ?';
	//削除対象のクーポンID
        $arrValIn = array($coupon_id);
        $objQuery->update($table, $sqlval, $where, $arrValIn);
        $objQuery->commit();
    }

}
